<?php

namespace Schaffen\Core\PaymentForm\Models;

use Illuminate\Database\Eloquent\Model;
use Schaffen\Core\Person\Models\Person;

class PaymentForm extends Model
{
   protected $useValidateRules = true;
   protected $rules = [
      'fop_descricao' => 'required|string|max:80',
      'fop_prazo' => 'required|integer',
      'fop_codigo_pagamento_sefaz' => 'nullable|string|max:10',
      'fop_bandeira' => 'nullable|integer',
      'fop_multa_percentual' => 'required|numeric',
      'fop_juros_percentual' => 'required|numeric',
      'fop_juros_tipo' => 'required|string|max:1',
      'fop_numero_maximo_parcelas' => 'nullable|integer',
      'fop_dias_protesto' => 'nullable|integer',
      'fop_vencimento_dia_fixo' => 'required|integer',
      'fop_vencimento_dia' => 'nullable|integer',
      'fop_vencimento_numero_dias' => 'nullable|integer',
      'fop_fatura_pessoa_especifica' => 'required|integer',
      'fop_fk_pes_codigo' => 'nullable|integer',
   ];

   protected $validationMessages = [
      'fop_descricao.required' => "O campo 'descricao' é obrigatório.",
      'fop_descricao.max' => "O campo 'descricao' excede o tamanho máximo de 80 caracteres.",
      'fop_prazo.required' => "O campo 'prazo' é obrigatório.",
      'fop_prazo.integer' => "O formato do campo 'prazo' é inválido (informar número inteiro).",
      'fop_codigo_pagamento_sefaz.max' => "O campo 'codigo_pagamento_sefaz' excede o tamanho máximo de 10 caracteres.",
      'fop_bandeira.integer' => "O formato do campo 'bandeira' é inválido (informar número inteiro).",
      'fop_multa_percentual.required' => "O campo 'multa_percentual' é obrigatório.",
      'fop_multa_percentual.numeric' => "O formato do campo 'multa_percentual' é inválido (informar apenas números).",
      'fop_juros_percentual.required' => "O campo 'juros_percentual' é obrigatório.",
      'fop_juros_percentual.numeric' => "O formato do campo 'juros_percentual' é inválido (informar apenas números).",
      'fop_juros_tipo.required' => "O campo 'juros_tipo' é obrigatório.",
      'fop_juros_tipo.max' => "O campo 'juros_tipo' excede o tamanho máximo de 1 caracteres.",
      'fop_numero_maximo_parcelas.integer' => "O formato do campo 'numero_maximo_parcelas' é inválido (informar número inteiro).",
      'fop_dias_protesto.integer' => "O formato do campo 'dias_protesto' é inválido (informar número inteiro).",
      'fop_vencimento_dia_fixo.required' => "O campo 'vencimento_dia_fixo' é obrigatório.",
      'fop_vencimento_dia_fixo.integer' => "O formato do campo 'vencimento_dia_fixo' é inválido (informar número inteiro).",
      'fop_vencimento_dia.integer' => "O formato do campo 'vencimento_dia' é inválido (informar número inteiro).",
      'fop_vencimento_numero_dias.integer' => "O formato do campo 'vencimento_numero_dias' é inválido (informar número inteiro).",
      'fop_fatura_pessoa_especifica.required' => "O campo 'fatura_pessoa_especifica' é obrigatório.",
      'fop_fatura_pessoa_especifica.integer' => "O formato do campo 'fatura_pessoa_especifica' é inválido (informar número inteiro).",
      'fop_fk_pes_codigo.integer' => "O formato do campo 'fk_pes_codigo' é inválido (informar número inteiro).",
   ];

   protected $table = "movimentacao.forma_pagamento";
   protected $primaryKey = "fop_codigo";
   protected $fillable = ["fop_descricao","fop_prazo","fop_codigo_pagamento_sefaz",
      "fop_bandeira","fop_multa_percentual","fop_juros_percentual","fop_juros_tipo",
      "fop_numero_maximo_parcelas","fop_dias_protesto","fop_vencimento_dia_fixo",
      "fop_vencimento_dia","fop_vencimento_numero_dias","fop_fatura_pessoa_especifica",
      "fop_fk_pes_codigo"];
   const CREATED_AT = "fop_date_insert";
   const CREATED_BY = "fop_user_insert";
   const UPDATED_AT = "fop_date_update";
   const UPDATED_BY = "fop_user_update";

   protected $with = ["pessoa"];

   protected $casts = [
      'fop_vencimento_dia_fixo' => 'string',
      'fop_fatura_pessoa_especifica' => 'string'
   ];

   public function pessoa(){
      return $this->belongsTo(Person::class, "fop_fk_pes_codigo")->select("pes_codigo", "pes_nome");
   }

   public static function getBandeiras()
   {
      return [
         ["codigo" => 3, "descricao" => "A. Express"],
         ["codigo" => 2, "descricao" => "Mastercard"],
         ["codigo" => 99, "descricao" => "Outros"],
         ["codigo" => 4, "descricao" => "Sorocred"],
         ["codigo" => 1, "descricao" => "Visa"]
      ];
   }
}
